@@ -21,7 +21,7 @@ class Step:
         self.step = "St"
         self.paramsFile = 'Step.properties'
         self.logger = 'logStep'
-        self.logFile = self.getRelativeFile('../logs/Step.log')
+        self.logFile = self.getRelativeFile(os.getcwd() +'\../logs/Step.log')
 
     # Needed for relative paths
     def getRelativeFile(self, filename):
@@ -66,7 +66,7 @@ class Step:
     # Load parameters from file
     def loadParams(self, filename):
         configs = Properties()
-        filename = self.getRelativeFile('../params/' + filename)
+        filename = self.getRelativeFile(os.getcwd() + '\../params/' + filename)
         with open(filename, 'rb') as config_file:
             configs.load(config_file)
             config_file.close()
@@ -104,7 +104,7 @@ class Step:
 
     # Reading taskID from text file
     def setTaskID(self):
-        with open(self.getRelativeFile('../params/Identifier.txt')) as f:
+        with open(self.getRelativeFile(os.getcwd() +'\../params/Identifier.txt')) as f:
             lines = f.readlines()
         self.taskID = lines[0]
         f.close()
